import { MotiPressableContext } from './context';
import type { MotiPressableInteractionProp } from './types';
declare type Factory = (containers: MotiPressableContext['containers']) => ReturnType<MotiPressableInteractionProp>;
/**
 * `useMotiPressables` lets you access the interaction state of *all* parent `MotiPressable` components.
 *
 * This offers more complex use-cases over `useMotiPressable`, which only lets you access the interaction state of a single parent `MotiPressable` at a time.
 *
 * Say you have a parent pressable, with a list of items:
 *
 * ```tsx
 * <MotiPressable id="list">
 *   {items.map(({ id }) => (
 *     <MotiPressable id={'item-' + id} key={id}>
 *       <Item id={id}  />
 *     </MotiPressable>
 *   )}
 * </MotiPressable>
 * ```
 *
 * Then, in your component, you can access each unique `MotiPressable`'s interaction state:
 *
 * ```tsx
 * const Item = ({ id }) => {
 *  const state = useMotiPressables((containers) => {
 *    'worklet'
 *
 *    const list = containers.list.value
 *    const item = containers.['item-' + id].value
 *
 *    // when hovering a list,
 *    // fade out all items except the one actually hovered
 *
 *    let opacity = 1
 *    if (item.hovered || item.pressed) {
 *      opacity = 1
 *    } else if (list.hovered) {
 *      opacity = 0.7
 *    }
 *
 *    return {
 *      opacity,
 *    }
 *  })
 *
 *  return <MotiView state={state} />
 * }
 * ```
 *
 * Example shown [here](https://twitter.com/FernandoTheRojo/status/1430717474778066944)
 *
 * <img height={300} width={400} src="https://pbs.twimg.com/media/E9rqA35XIAQmbuk?format=jpg&name=4096x4096" />
 */
export declare function useMotiPressables(
/**
 * Function that receives the interaction state from all parent containers and returns a style object/
 * @worklet
 */
factory: Factory, deps?: readonly any[]): {
    __state: Readonly<{
        value: {
            backfaceVisibility?: "visible" | "hidden" | import("../..").SequenceItem<"visible" | "hidden" | undefined>[] | {
                value: "visible" | "hidden" | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<"visible" | "hidden" | import("../..").SequenceItem<"visible" | "hidden" | undefined>[] | undefined>;
            } | undefined;
            backgroundColor?: string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | {
                value: string | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | undefined>;
            } | undefined;
            borderBottomColor?: string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | {
                value: string | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | undefined>;
            } | undefined;
            borderBottomEndRadius?: number | import("../..").SequenceItem<number | undefined>[] | {
                value: number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
            } | undefined;
            borderBottomLeftRadius?: number | import("../..").SequenceItem<number | undefined>[] | {
                value: number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
            } | undefined;
            borderBottomRightRadius?: number | import("../..").SequenceItem<number | undefined>[] | {
                value: number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
            } | undefined;
            borderBottomStartRadius?: number | import("../..").SequenceItem<number | undefined>[] | {
                value: number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
            } | undefined;
            borderBottomWidth?: number | import("../..").SequenceItem<number | undefined>[] | {
                value: number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
            } | undefined;
            borderColor?: string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | {
                value: string | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | undefined>;
            } | undefined;
            borderEndColor?: string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | {
                value: string | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | undefined>;
            } | undefined;
            borderLeftColor?: string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | {
                value: string | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | undefined>;
            } | undefined;
            borderLeftWidth?: number | import("../..").SequenceItem<number | undefined>[] | {
                value: number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
            } | undefined;
            borderRadius?: number | import("../..").SequenceItem<number | undefined>[] | {
                value: number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
            } | undefined;
            borderRightColor?: string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | {
                value: string | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | undefined>;
            } | undefined;
            borderRightWidth?: number | import("../..").SequenceItem<number | undefined>[] | {
                value: number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
            } | undefined;
            borderStartColor?: string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | {
                value: string | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | undefined>;
            } | undefined;
            borderStyle?: "solid" | "dotted" | "dashed" | import("../..").SequenceItem<"solid" | "dotted" | "dashed" | undefined>[] | {
                value: "solid" | "dotted" | "dashed" | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<"solid" | "dotted" | "dashed" | import("../..").SequenceItem<"solid" | "dotted" | "dashed" | undefined>[] | undefined>;
            } | undefined;
            borderTopColor?: string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | {
                value: string | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | undefined>;
            } | undefined;
            borderTopEndRadius?: number | import("../..").SequenceItem<number | undefined>[] | {
                value: number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
            } | undefined;
            borderTopLeftRadius?: number | import("../..").SequenceItem<number | undefined>[] | {
                value: number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
            } | undefined;
            borderTopRightRadius?: number | import("../..").SequenceItem<number | undefined>[] | {
                value: number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
            } | undefined;
            borderTopStartRadius?: number | import("../..").SequenceItem<number | undefined>[] | {
                value: number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
            } | undefined;
            borderTopWidth?: number | import("../..").SequenceItem<number | undefined>[] | {
                value: number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
            } | undefined;
            borderWidth?: number | import("../..").SequenceItem<number | undefined>[] | {
                value: number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
            } | undefined;
            opacity?: number | import("../..").SequenceItem<number | undefined>[] | {
                value: number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
            } | undefined;
            testID?: string | import("../..").SequenceItem<string | undefined>[] | {
                value: string | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | import("../..").SequenceItem<string | undefined>[] | undefined>;
            } | undefined;
            elevation?: number | import("../..").SequenceItem<number | undefined>[] | {
                value: number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
            } | undefined;
            alignContent?: "flex-start" | "flex-end" | "center" | "stretch" | "space-between" | "space-around" | import("../..").SequenceItem<"flex-start" | "flex-end" | "center" | "stretch" | "space-between" | "space-around" | undefined>[] | {
                value: "flex-start" | "flex-end" | "center" | "stretch" | "space-between" | "space-around" | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<"flex-start" | "flex-end" | "center" | "stretch" | "space-between" | "space-around" | import("../..").SequenceItem<"flex-start" | "flex-end" | "center" | "stretch" | "space-between" | "space-around" | undefined>[] | undefined>;
            } | undefined;
            alignItems?: "flex-start" | "flex-end" | "center" | "stretch" | "baseline" | import("../..").SequenceItem<"flex-start" | "flex-end" | "center" | "stretch" | "baseline" | undefined>[] | {
                value: "flex-start" | "flex-end" | "center" | "stretch" | "baseline" | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<"flex-start" | "flex-end" | "center" | "stretch" | "baseline" | import("../..").SequenceItem<"flex-start" | "flex-end" | "center" | "stretch" | "baseline" | undefined>[] | undefined>;
            } | undefined;
            alignSelf?: "flex-start" | "flex-end" | "center" | "stretch" | "baseline" | "auto" | import("../..").SequenceItem<"flex-start" | "flex-end" | "center" | "stretch" | "baseline" | "auto" | undefined>[] | {
                value: "flex-start" | "flex-end" | "center" | "stretch" | "baseline" | "auto" | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<"flex-start" | "flex-end" | "center" | "stretch" | "baseline" | "auto" | import("../..").SequenceItem<"flex-start" | "flex-end" | "center" | "stretch" | "baseline" | "auto" | undefined>[] | undefined>;
            } | undefined;
            aspectRatio?: number | import("../..").SequenceItem<number | undefined>[] | {
                value: number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
            } | undefined;
            borderEndWidth?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            borderStartWidth?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            bottom?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            display?: "flex" | "none" | import("../..").SequenceItem<"flex" | "none" | undefined>[] | {
                value: "flex" | "none" | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<"flex" | "none" | import("../..").SequenceItem<"flex" | "none" | undefined>[] | undefined>;
            } | undefined;
            end?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            flex?: number | import("../..").SequenceItem<number | undefined>[] | {
                value: number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
            } | undefined;
            flexBasis?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            flexDirection?: "row" | "column" | "row-reverse" | "column-reverse" | import("../..").SequenceItem<"row" | "column" | "row-reverse" | "column-reverse" | undefined>[] | {
                value: "row" | "column" | "row-reverse" | "column-reverse" | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<"row" | "column" | "row-reverse" | "column-reverse" | import("../..").SequenceItem<"row" | "column" | "row-reverse" | "column-reverse" | undefined>[] | undefined>;
            } | undefined;
            flexGrow?: number | import("../..").SequenceItem<number | undefined>[] | {
                value: number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
            } | undefined;
            flexShrink?: number | import("../..").SequenceItem<number | undefined>[] | {
                value: number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
            } | undefined;
            flexWrap?: "wrap" | "nowrap" | "wrap-reverse" | import("../..").SequenceItem<"wrap" | "nowrap" | "wrap-reverse" | undefined>[] | {
                value: "wrap" | "nowrap" | "wrap-reverse" | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<"wrap" | "nowrap" | "wrap-reverse" | import("../..").SequenceItem<"wrap" | "nowrap" | "wrap-reverse" | undefined>[] | undefined>;
            } | undefined;
            height?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            justifyContent?: "flex-start" | "flex-end" | "center" | "space-between" | "space-around" | "space-evenly" | import("../..").SequenceItem<"flex-start" | "flex-end" | "center" | "space-between" | "space-around" | "space-evenly" | undefined>[] | {
                value: "flex-start" | "flex-end" | "center" | "space-between" | "space-around" | "space-evenly" | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<"flex-start" | "flex-end" | "center" | "space-between" | "space-around" | "space-evenly" | import("../..").SequenceItem<"flex-start" | "flex-end" | "center" | "space-between" | "space-around" | "space-evenly" | undefined>[] | undefined>;
            } | undefined;
            left?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            margin?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            marginBottom?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            marginEnd?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            marginHorizontal?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            marginLeft?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            marginRight?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            marginStart?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            marginTop?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            marginVertical?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            maxHeight?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            maxWidth?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            minHeight?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            minWidth?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            overflow?: "visible" | "hidden" | "scroll" | import("../..").SequenceItem<"visible" | "hidden" | "scroll" | undefined>[] | {
                value: "visible" | "hidden" | "scroll" | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<"visible" | "hidden" | "scroll" | import("../..").SequenceItem<"visible" | "hidden" | "scroll" | undefined>[] | undefined>;
            } | undefined;
            padding?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            paddingBottom?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            paddingEnd?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            paddingHorizontal?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            paddingLeft?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            paddingRight?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            paddingStart?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            paddingTop?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            paddingVertical?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            position?: "absolute" | "relative" | import("../..").SequenceItem<"absolute" | "relative" | undefined>[] | {
                value: "absolute" | "relative" | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<"absolute" | "relative" | import("../..").SequenceItem<"absolute" | "relative" | undefined>[] | undefined>;
            } | undefined;
            right?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            start?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            top?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            width?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                value: string | number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
            } | undefined;
            zIndex?: number | import("../..").SequenceItem<number | undefined>[] | {
                value: number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
            } | undefined;
            direction?: "inherit" | "ltr" | "rtl" | import("../..").SequenceItem<"inherit" | "ltr" | "rtl" | undefined>[] | {
                value: "inherit" | "ltr" | "rtl" | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<"inherit" | "ltr" | "rtl" | import("../..").SequenceItem<"inherit" | "ltr" | "rtl" | undefined>[] | undefined>;
            } | undefined;
            shadowColor?: string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | {
                value: string | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | undefined>;
            } | undefined;
            shadowOffset?: {
                width: number;
                height: number;
            } | import("../..").SequenceItem<{
                width: number;
                height: number;
            } | undefined>[] | {
                value: undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<{
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<{
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            shadowOpacity?: number | import("../..").SequenceItem<number | undefined>[] | {
                value: number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
            } | undefined;
            shadowRadius?: number | import("../..").SequenceItem<number | undefined>[] | {
                value: number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
            } | undefined;
            transformMatrix?: number[] | import("../..").SequenceItem<number[] | undefined>[] | {
                value: undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<number[] | import("../..").SequenceItem<number[] | undefined>[] | undefined>;
            } | undefined;
            rotation?: number | import("../..").SequenceItem<number | undefined>[] | {
                value: number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
            } | undefined;
            scaleX?: number | (string & {}) | import("../..").SequenceItem<number | (string & {}) | undefined>[] | {
                value: number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<number | (string & {}) | import("../..").SequenceItem<number | (string & {}) | undefined>[] | undefined>;
            } | undefined;
            scaleY?: number | (string & {}) | import("../..").SequenceItem<number | (string & {}) | undefined>[] | {
                value: number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<number | (string & {}) | import("../..").SequenceItem<number | (string & {}) | undefined>[] | undefined>;
            } | undefined;
            translateX?: number | (string & {}) | import("../..").SequenceItem<number | (string & {}) | undefined>[] | {
                value: number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<number | (string & {}) | import("../..").SequenceItem<number | (string & {}) | undefined>[] | undefined>;
            } | undefined;
            translateY?: number | (string & {}) | import("../..").SequenceItem<number | (string & {}) | undefined>[] | {
                value: number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<number | (string & {}) | import("../..").SequenceItem<number | (string & {}) | undefined>[] | undefined>;
            } | undefined;
            perspective?: number | (string & {}) | import("../..").SequenceItem<number | (string & {}) | undefined>[] | {
                value: number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<number | (string & {}) | import("../..").SequenceItem<number | (string & {}) | undefined>[] | undefined>;
            } | undefined;
            rotate?: string | (string & {}) | import("../..").SequenceItem<string | (string & {}) | undefined>[] | {
                value: string | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | (string & {}) | import("../..").SequenceItem<string | (string & {}) | undefined>[] | undefined>;
            } | undefined;
            rotateX?: string | (string & {}) | import("../..").SequenceItem<string | (string & {}) | undefined>[] | {
                value: string | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | (string & {}) | import("../..").SequenceItem<string | (string & {}) | undefined>[] | undefined>;
            } | undefined;
            rotateY?: string | (string & {}) | import("../..").SequenceItem<string | (string & {}) | undefined>[] | {
                value: string | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | (string & {}) | import("../..").SequenceItem<string | (string & {}) | undefined>[] | undefined>;
            } | undefined;
            rotateZ?: string | (string & {}) | import("../..").SequenceItem<string | (string & {}) | undefined>[] | {
                value: string | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | (string & {}) | import("../..").SequenceItem<string | (string & {}) | undefined>[] | undefined>;
            } | undefined;
            scale?: number | (string & {}) | import("../..").SequenceItem<number | (string & {}) | undefined>[] | {
                value: number | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<number | (string & {}) | import("../..").SequenceItem<number | (string & {}) | undefined>[] | undefined>;
            } | undefined;
            skewX?: string | (string & {}) | import("../..").SequenceItem<string | (string & {}) | undefined>[] | {
                value: string | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | (string & {}) | import("../..").SequenceItem<string | (string & {}) | undefined>[] | undefined>;
            } | undefined;
            skewY?: string | (string & {}) | import("../..").SequenceItem<string | (string & {}) | undefined>[] | {
                value: string | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | (string & {}) | import("../..").SequenceItem<string | (string & {}) | undefined>[] | undefined>;
            } | undefined;
            transform?: Partial<{} & {
                scaleX?: number | (string & {}) | import("../..").SequenceItem<number | (string & {})>[] | undefined;
                scaleY?: number | (string & {}) | import("../..").SequenceItem<number | (string & {})>[] | undefined;
                translateX?: number | (string & {}) | import("../..").SequenceItem<number | (string & {})>[] | undefined;
                translateY?: number | (string & {}) | import("../..").SequenceItem<number | (string & {})>[] | undefined;
                perspective?: number | (string & {}) | import("../..").SequenceItem<number | (string & {})>[] | undefined;
                rotate?: string | (string & {}) | import("../..").SequenceItem<string | (string & {})>[] | undefined;
                rotateX?: string | (string & {}) | import("../..").SequenceItem<string | (string & {})>[] | undefined;
                rotateY?: string | (string & {}) | import("../..").SequenceItem<string | (string & {})>[] | undefined;
                rotateZ?: string | (string & {}) | import("../..").SequenceItem<string | (string & {})>[] | undefined;
                scale?: number | (string & {}) | import("../..").SequenceItem<number | (string & {})>[] | undefined;
                skewX?: string | (string & {}) | import("../..").SequenceItem<string | (string & {})>[] | undefined;
                skewY?: string | (string & {}) | import("../..").SequenceItem<string | (string & {})>[] | undefined;
            } & import("../..").StyleValueWithSequenceArraysWithTransform>[] | {
                value: undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<Partial<{} & {
                    scaleX?: number | (string & {}) | import("../..").SequenceItem<number | (string & {})>[] | undefined;
                    scaleY?: number | (string & {}) | import("../..").SequenceItem<number | (string & {})>[] | undefined;
                    translateX?: number | (string & {}) | import("../..").SequenceItem<number | (string & {})>[] | undefined;
                    translateY?: number | (string & {}) | import("../..").SequenceItem<number | (string & {})>[] | undefined;
                    perspective?: number | (string & {}) | import("../..").SequenceItem<number | (string & {})>[] | undefined;
                    rotate?: string | (string & {}) | import("../..").SequenceItem<string | (string & {})>[] | undefined;
                    rotateX?: string | (string & {}) | import("../..").SequenceItem<string | (string & {})>[] | undefined;
                    rotateY?: string | (string & {}) | import("../..").SequenceItem<string | (string & {})>[] | undefined;
                    rotateZ?: string | (string & {}) | import("../..").SequenceItem<string | (string & {})>[] | undefined;
                    scale?: number | (string & {}) | import("../..").SequenceItem<number | (string & {})>[] | undefined;
                    skewX?: string | (string & {}) | import("../..").SequenceItem<string | (string & {})>[] | undefined;
                    skewY?: string | (string & {}) | import("../..").SequenceItem<string | (string & {})>[] | undefined;
                } & import("../..").StyleValueWithSequenceArraysWithTransform>[] | undefined>;
            } | undefined;
        } | Readonly<{
            value: {
                backfaceVisibility?: "visible" | "hidden" | import("../..").SequenceItem<"visible" | "hidden" | undefined>[] | {
                    value: "visible" | "hidden" | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<"visible" | "hidden" | import("../..").SequenceItem<"visible" | "hidden" | undefined>[] | undefined>;
                } | undefined;
                backgroundColor?: string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | {
                    value: string | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | undefined>;
                } | undefined;
                borderBottomColor?: string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | {
                    value: string | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | undefined>;
                } | undefined;
                borderBottomEndRadius?: number | import("../..").SequenceItem<number | undefined>[] | {
                    value: number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
                } | undefined;
                borderBottomLeftRadius?: number | import("../..").SequenceItem<number | undefined>[] | {
                    value: number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
                } | undefined;
                borderBottomRightRadius?: number | import("../..").SequenceItem<number | undefined>[] | {
                    value: number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
                } | undefined;
                borderBottomStartRadius?: number | import("../..").SequenceItem<number | undefined>[] | {
                    value: number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
                } | undefined;
                borderBottomWidth?: number | import("../..").SequenceItem<number | undefined>[] | {
                    value: number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
                } | undefined;
                borderColor?: string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | {
                    value: string | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | undefined>;
                } | undefined;
                borderEndColor?: string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | {
                    value: string | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | undefined>;
                } | undefined;
                borderLeftColor?: string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | {
                    value: string | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | undefined>;
                } | undefined;
                borderLeftWidth?: number | import("../..").SequenceItem<number | undefined>[] | {
                    value: number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
                } | undefined;
                borderRadius?: number | import("../..").SequenceItem<number | undefined>[] | {
                    value: number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
                } | undefined;
                borderRightColor?: string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | {
                    value: string | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | undefined>;
                } | undefined;
                borderRightWidth?: number | import("../..").SequenceItem<number | undefined>[] | {
                    value: number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
                } | undefined;
                borderStartColor?: string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | {
                    value: string | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | undefined>;
                } | undefined;
                borderStyle?: "solid" | "dotted" | "dashed" | import("../..").SequenceItem<"solid" | "dotted" | "dashed" | undefined>[] | {
                    value: "solid" | "dotted" | "dashed" | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<"solid" | "dotted" | "dashed" | import("../..").SequenceItem<"solid" | "dotted" | "dashed" | undefined>[] | undefined>;
                } | undefined;
                borderTopColor?: string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | {
                    value: string | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | undefined>;
                } | undefined;
                borderTopEndRadius?: number | import("../..").SequenceItem<number | undefined>[] | {
                    value: number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
                } | undefined;
                borderTopLeftRadius?: number | import("../..").SequenceItem<number | undefined>[] | {
                    value: number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
                } | undefined;
                borderTopRightRadius?: number | import("../..").SequenceItem<number | undefined>[] | {
                    value: number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
                } | undefined;
                borderTopStartRadius?: number | import("../..").SequenceItem<number | undefined>[] | {
                    value: number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
                } | undefined;
                borderTopWidth?: number | import("../..").SequenceItem<number | undefined>[] | {
                    value: number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
                } | undefined;
                borderWidth?: number | import("../..").SequenceItem<number | undefined>[] | {
                    value: number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
                } | undefined;
                opacity?: number | import("../..").SequenceItem<number | undefined>[] | {
                    value: number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
                } | undefined;
                testID?: string | import("../..").SequenceItem<string | undefined>[] | {
                    value: string | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | import("../..").SequenceItem<string | undefined>[] | undefined>;
                } | undefined;
                elevation?: number | import("../..").SequenceItem<number | undefined>[] | {
                    value: number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
                } | undefined;
                alignContent?: "flex-start" | "flex-end" | "center" | "stretch" | "space-between" | "space-around" | import("../..").SequenceItem<"flex-start" | "flex-end" | "center" | "stretch" | "space-between" | "space-around" | undefined>[] | {
                    value: "flex-start" | "flex-end" | "center" | "stretch" | "space-between" | "space-around" | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<"flex-start" | "flex-end" | "center" | "stretch" | "space-between" | "space-around" | import("../..").SequenceItem<"flex-start" | "flex-end" | "center" | "stretch" | "space-between" | "space-around" | undefined>[] | undefined>;
                } | undefined;
                alignItems?: "flex-start" | "flex-end" | "center" | "stretch" | "baseline" | import("../..").SequenceItem<"flex-start" | "flex-end" | "center" | "stretch" | "baseline" | undefined>[] | {
                    value: "flex-start" | "flex-end" | "center" | "stretch" | "baseline" | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<"flex-start" | "flex-end" | "center" | "stretch" | "baseline" | import("../..").SequenceItem<"flex-start" | "flex-end" | "center" | "stretch" | "baseline" | undefined>[] | undefined>;
                } | undefined;
                alignSelf?: "flex-start" | "flex-end" | "center" | "stretch" | "baseline" | "auto" | import("../..").SequenceItem<"flex-start" | "flex-end" | "center" | "stretch" | "baseline" | "auto" | undefined>[] | {
                    value: "flex-start" | "flex-end" | "center" | "stretch" | "baseline" | "auto" | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<"flex-start" | "flex-end" | "center" | "stretch" | "baseline" | "auto" | import("../..").SequenceItem<"flex-start" | "flex-end" | "center" | "stretch" | "baseline" | "auto" | undefined>[] | undefined>;
                } | undefined;
                aspectRatio?: number | import("../..").SequenceItem<number | undefined>[] | {
                    value: number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
                } | undefined;
                borderEndWidth?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                borderStartWidth?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                bottom?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                display?: "flex" | "none" | import("../..").SequenceItem<"flex" | "none" | undefined>[] | {
                    value: "flex" | "none" | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<"flex" | "none" | import("../..").SequenceItem<"flex" | "none" | undefined>[] | undefined>;
                } | undefined;
                end?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                flex?: number | import("../..").SequenceItem<number | undefined>[] | {
                    value: number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
                } | undefined;
                flexBasis?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                flexDirection?: "row" | "column" | "row-reverse" | "column-reverse" | import("../..").SequenceItem<"row" | "column" | "row-reverse" | "column-reverse" | undefined>[] | {
                    value: "row" | "column" | "row-reverse" | "column-reverse" | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<"row" | "column" | "row-reverse" | "column-reverse" | import("../..").SequenceItem<"row" | "column" | "row-reverse" | "column-reverse" | undefined>[] | undefined>;
                } | undefined;
                flexGrow?: number | import("../..").SequenceItem<number | undefined>[] | {
                    value: number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
                } | undefined;
                flexShrink?: number | import("../..").SequenceItem<number | undefined>[] | {
                    value: number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
                } | undefined;
                flexWrap?: "wrap" | "nowrap" | "wrap-reverse" | import("../..").SequenceItem<"wrap" | "nowrap" | "wrap-reverse" | undefined>[] | {
                    value: "wrap" | "nowrap" | "wrap-reverse" | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<"wrap" | "nowrap" | "wrap-reverse" | import("../..").SequenceItem<"wrap" | "nowrap" | "wrap-reverse" | undefined>[] | undefined>;
                } | undefined;
                height?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                justifyContent?: "flex-start" | "flex-end" | "center" | "space-between" | "space-around" | "space-evenly" | import("../..").SequenceItem<"flex-start" | "flex-end" | "center" | "space-between" | "space-around" | "space-evenly" | undefined>[] | {
                    value: "flex-start" | "flex-end" | "center" | "space-between" | "space-around" | "space-evenly" | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<"flex-start" | "flex-end" | "center" | "space-between" | "space-around" | "space-evenly" | import("../..").SequenceItem<"flex-start" | "flex-end" | "center" | "space-between" | "space-around" | "space-evenly" | undefined>[] | undefined>;
                } | undefined;
                left?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                margin?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                marginBottom?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                marginEnd?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                marginHorizontal?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                marginLeft?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                marginRight?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                marginStart?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                marginTop?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                marginVertical?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                maxHeight?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                maxWidth?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                minHeight?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                minWidth?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                overflow?: "visible" | "hidden" | "scroll" | import("../..").SequenceItem<"visible" | "hidden" | "scroll" | undefined>[] | {
                    value: "visible" | "hidden" | "scroll" | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<"visible" | "hidden" | "scroll" | import("../..").SequenceItem<"visible" | "hidden" | "scroll" | undefined>[] | undefined>;
                } | undefined;
                padding?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                paddingBottom?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                paddingEnd?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                paddingHorizontal?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                paddingLeft?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                paddingRight?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                paddingStart?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                paddingTop?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                paddingVertical?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                position?: "absolute" | "relative" | import("../..").SequenceItem<"absolute" | "relative" | undefined>[] | {
                    value: "absolute" | "relative" | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<"absolute" | "relative" | import("../..").SequenceItem<"absolute" | "relative" | undefined>[] | undefined>;
                } | undefined;
                right?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                start?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                top?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                width?: string | number | import("../..").SequenceItem<string | number | undefined>[] | {
                    value: string | number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | import("../..").SequenceItem<string | number | undefined>[] | undefined>;
                } | undefined;
                zIndex?: number | import("../..").SequenceItem<number | undefined>[] | {
                    value: number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
                } | undefined;
                direction?: "inherit" | "ltr" | "rtl" | import("../..").SequenceItem<"inherit" | "ltr" | "rtl" | undefined>[] | {
                    value: "inherit" | "ltr" | "rtl" | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<"inherit" | "ltr" | "rtl" | import("../..").SequenceItem<"inherit" | "ltr" | "rtl" | undefined>[] | undefined>;
                } | undefined;
                shadowColor?: string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | {
                    value: string | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | typeof import("react-native").OpaqueColorValue | import("../..").SequenceItem<string | typeof import("react-native").OpaqueColorValue | undefined>[] | undefined>;
                } | undefined;
                shadowOffset?: {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<{
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<{
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<{
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                shadowOpacity?: number | import("../..").SequenceItem<number | undefined>[] | {
                    value: number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
                } | undefined;
                shadowRadius?: number | import("../..").SequenceItem<number | undefined>[] | {
                    value: number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
                } | undefined;
                transformMatrix?: number[] | import("../..").SequenceItem<number[] | undefined>[] | {
                    value: undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<number[] | import("../..").SequenceItem<number[] | undefined>[] | undefined>;
                } | undefined;
                rotation?: number | import("../..").SequenceItem<number | undefined>[] | {
                    value: number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<number | import("../..").SequenceItem<number | undefined>[] | undefined>;
                } | undefined;
                scaleX?: number | (string & {}) | import("../..").SequenceItem<number | (string & {}) | undefined>[] | {
                    value: number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<number | (string & {}) | import("../..").SequenceItem<number | (string & {}) | undefined>[] | undefined>;
                } | undefined;
                scaleY?: number | (string & {}) | import("../..").SequenceItem<number | (string & {}) | undefined>[] | {
                    value: number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<number | (string & {}) | import("../..").SequenceItem<number | (string & {}) | undefined>[] | undefined>;
                } | undefined;
                translateX?: number | (string & {}) | import("../..").SequenceItem<number | (string & {}) | undefined>[] | {
                    value: number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<number | (string & {}) | import("../..").SequenceItem<number | (string & {}) | undefined>[] | undefined>;
                } | undefined;
                translateY?: number | (string & {}) | import("../..").SequenceItem<number | (string & {}) | undefined>[] | {
                    value: number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<number | (string & {}) | import("../..").SequenceItem<number | (string & {}) | undefined>[] | undefined>;
                } | undefined;
                perspective?: number | (string & {}) | import("../..").SequenceItem<number | (string & {}) | undefined>[] | {
                    value: number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<number | (string & {}) | import("../..").SequenceItem<number | (string & {}) | undefined>[] | undefined>;
                } | undefined;
                rotate?: string | (string & {}) | import("../..").SequenceItem<string | (string & {}) | undefined>[] | {
                    value: string | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | (string & {}) | import("../..").SequenceItem<string | (string & {}) | undefined>[] | undefined>;
                } | undefined;
                rotateX?: string | (string & {}) | import("../..").SequenceItem<string | (string & {}) | undefined>[] | {
                    value: string | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | (string & {}) | import("../..").SequenceItem<string | (string & {}) | undefined>[] | undefined>;
                } | undefined;
                rotateY?: string | (string & {}) | import("../..").SequenceItem<string | (string & {}) | undefined>[] | {
                    value: string | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | (string & {}) | import("../..").SequenceItem<string | (string & {}) | undefined>[] | undefined>;
                } | undefined;
                rotateZ?: string | (string & {}) | import("../..").SequenceItem<string | (string & {}) | undefined>[] | {
                    value: string | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | (string & {}) | import("../..").SequenceItem<string | (string & {}) | undefined>[] | undefined>;
                } | undefined;
                scale?: number | (string & {}) | import("../..").SequenceItem<number | (string & {}) | undefined>[] | {
                    value: number | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<number | (string & {}) | import("../..").SequenceItem<number | (string & {}) | undefined>[] | undefined>;
                } | undefined;
                skewX?: string | (string & {}) | import("../..").SequenceItem<string | (string & {}) | undefined>[] | {
                    value: string | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | (string & {}) | import("../..").SequenceItem<string | (string & {}) | undefined>[] | undefined>;
                } | undefined;
                skewY?: string | (string & {}) | import("../..").SequenceItem<string | (string & {}) | undefined>[] | {
                    value: string | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | (string & {}) | import("../..").SequenceItem<string | (string & {}) | undefined>[] | undefined>;
                } | undefined;
                transform?: Partial<{} & {
                    scaleX?: number | (string & {}) | import("../..").SequenceItem<number | (string & {})>[] | undefined;
                    scaleY?: number | (string & {}) | import("../..").SequenceItem<number | (string & {})>[] | undefined;
                    translateX?: number | (string & {}) | import("../..").SequenceItem<number | (string & {})>[] | undefined;
                    translateY?: number | (string & {}) | import("../..").SequenceItem<number | (string & {})>[] | undefined;
                    perspective?: number | (string & {}) | import("../..").SequenceItem<number | (string & {})>[] | undefined;
                    rotate?: string | (string & {}) | import("../..").SequenceItem<string | (string & {})>[] | undefined;
                    rotateX?: string | (string & {}) | import("../..").SequenceItem<string | (string & {})>[] | undefined;
                    rotateY?: string | (string & {}) | import("../..").SequenceItem<string | (string & {})>[] | undefined;
                    rotateZ?: string | (string & {}) | import("../..").SequenceItem<string | (string & {})>[] | undefined;
                    scale?: number | (string & {}) | import("../..").SequenceItem<number | (string & {})>[] | undefined;
                    skewX?: string | (string & {}) | import("../..").SequenceItem<string | (string & {})>[] | undefined;
                    skewY?: string | (string & {}) | import("../..").SequenceItem<string | (string & {})>[] | undefined;
                } & import("../..").StyleValueWithSequenceArraysWithTransform>[] | {
                    value: undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<Partial<{} & {
                        scaleX?: number | (string & {}) | import("../..").SequenceItem<number | (string & {})>[] | undefined;
                        scaleY?: number | (string & {}) | import("../..").SequenceItem<number | (string & {})>[] | undefined;
                        translateX?: number | (string & {}) | import("../..").SequenceItem<number | (string & {})>[] | undefined;
                        translateY?: number | (string & {}) | import("../..").SequenceItem<number | (string & {})>[] | undefined;
                        perspective?: number | (string & {}) | import("../..").SequenceItem<number | (string & {})>[] | undefined;
                        rotate?: string | (string & {}) | import("../..").SequenceItem<string | (string & {})>[] | undefined;
                        rotateX?: string | (string & {}) | import("../..").SequenceItem<string | (string & {})>[] | undefined;
                        rotateY?: string | (string & {}) | import("../..").SequenceItem<string | (string & {})>[] | undefined;
                        rotateZ?: string | (string & {}) | import("../..").SequenceItem<string | (string & {})>[] | undefined;
                        scale?: number | (string & {}) | import("../..").SequenceItem<number | (string & {})>[] | undefined;
                        skewX?: string | (string & {}) | import("../..").SequenceItem<string | (string & {})>[] | undefined;
                        skewY?: string | (string & {}) | import("../..").SequenceItem<string | (string & {})>[] | undefined;
                    } & import("../..").StyleValueWithSequenceArraysWithTransform>[] | undefined>;
                } | undefined;
            };
        }>;
    }>;
};
export {};
